/// <reference types="react" />
import React$1 from 'react';

declare type Easing = "ease-in" | "ease-out" | "ease-in-out" | "linear" | "cubic-bezier(0.25, 0.1, 0.25, 1.0)" | "cubic-bezier(0.42, 0.0, 1.0, 1.0)" | "cubic-bezier(0.0, 0.0, 0.58, 1.0)" | "cubic-bezier(0.42, 0.0, 0.58, 1.0)" | "linear(0, 1)" | "steps(4, end)";
interface CommonProps {
    /**
     * Sets color of the indicator/throbber
     */
    color?: string | string[];
    /**
     * Sets size of the indicator/throbber
     */
    size?: "small" | "medium" | "large";
    /**
     * Supply CSS in JS styles
     */
    style?: React.CSSProperties;
    text?: string | boolean;
    /**
     * Sets color of text
     */
    textColor?: string;
    /**
     * Unitless number `-5` through `5`. (`-`)Slows down, (`+`)speeds up animation.
     */
    speedPlus?: -5 | -4 | -3 | -2 | -1 | 0 | 1 | 2 | 3 | 4 | 5;
    /**
     CSS easing function, e.g `linear`, `ease-in`
     *	@see {@link https://developer.mozilla.org/en-US/docs/Web/CSS/easing-function | MDN Docs}
     */
    easing?: Easing;
}

interface AtomProps extends CommonProps {
}

declare const _default$a: React$1.MemoExoticComponent<(props: AtomProps) => JSX.Element>;

interface CommetProps extends CommonProps {
}

declare const _default$9: React$1.MemoExoticComponent<(props: CommetProps) => JSX.Element>;

interface OrbitProgressProps extends CommonProps {
    /**
     * variant of an orbitting loading indicator. Defaults to `disc`.
     */
    variant?: "dotted" | "bubble-dotted" | "disc" | "split-disc" | "track-disc";
}

declare const _default$8: React$1.MemoExoticComponent<(props: OrbitProgressProps) => JSX.Element | null>;

interface FourSquareProps extends CommonProps {
}

declare const _default$7: React$1.MemoExoticComponent<(props: FourSquareProps) => JSX.Element>;

interface MosaicProps extends CommonProps {
}

declare const _default$6: React$1.MemoExoticComponent<(props: MosaicProps) => JSX.Element>;

interface RipleProps extends CommonProps {
}

declare const _default$5: React$1.MemoExoticComponent<(props: RipleProps) => JSX.Element>;

interface ThreeDotProps extends CommonProps {
    /**
     * Variant of a ThreeDot loading indicator. Defaults to `Pulsate`.
     */
    variant?: "pulsate" | "windmill" | "bob" | "brick-stack";
}

declare const _default$4: React$1.MemoExoticComponent<(props: ThreeDotProps) => JSX.Element | null>;

interface BlinkBlurProps extends CommonProps {
}

declare const _default$3: React$1.MemoExoticComponent<(props: BlinkBlurProps) => JSX.Element>;

interface TwistProps extends CommonProps {
}

declare const _default$2: React$1.MemoExoticComponent<(props: TwistProps) => JSX.Element>;

interface SlabProps extends CommonProps {
}

declare const _default$1: React$1.MemoExoticComponent<(props: SlabProps) => JSX.Element>;

interface LifeLineProps extends CommonProps {
}

declare const _default: React$1.MemoExoticComponent<(props: LifeLineProps) => JSX.Element>;

export { _default$a as Atom, _default$3 as BlinkBlur, _default$9 as Commet, _default$7 as FourSquare, _default as LifeLine, _default$6 as Mosaic, _default$8 as OrbitProgress, _default$5 as Riple, _default$1 as Slab, _default$4 as ThreeDot, _default$2 as TrophySpin };
